# py-ldlm

An LDLM (http://github.com/imoore76/ldlm) client library providing Python sync and async clients.

[![PyPI version](https://badge.fury.io/py/py-ldlm.svg)](https://badge.fury.io/py/py-ldlm)
[![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fimoore76%2Fpy-ldlm%2Fmain%2Fpyproject.toml)](https://github.com/imoore76/py-ldlm/blob/main/pyproject.toml)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Coverage Status](https://coveralls.io/repos/github/imoore76/py-ldlm/badge.svg)](https://coveralls.io/github/imoore76/py-ldlm)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/imoore76/py-ldlm/run_checks.yaml)
![CodeQL Workflow Status](https://github.com/imoore76/py-ldlm/actions/workflows/codeql.yml/badge.svg)

## Installation

```
pip install py-ldlm
```

## Usage

See full ducumentation at https://py-ldlm.readthedocs.io/

## License

Apache 2.0; see [`LICENSE`](LICENSE) for details.

## Contributing

See [`CONTRIBUTING.md`](CONTRIBUTING.md) for details.

## Disclaimer

This project is not an official Google project. It is not supported by Google and Google specifically disclaims all warranties as to its quality, merchantability, or fitness for a particular purpose.

